..
   Copyright (C) 2015 Jaakko Luttinen

   This file is licensed under the MIT License. See LICENSE for a text of the
   license.


Latent Dirichlet allocation
===========================

blaa blaa blaa..
